@@ -5,7 +5,7 @@ from .proxies import ProxiesService
 from .scraping import ScrapingService
 from .storage import StorageService
 from .universal import UniversalService
-from .crawl.index import ScrapingCrawlService
+from .crawl import ScrapingCrawlService
 from .captcha import CaptchaService
 
 __all__ = [
